@@ -50,9 +50,15 @@ static int dmapi_fd = -1;
 int
 dmi_init_service( char *versionstr )
 {
-	dmapi_fd = open( "/proc/fs/xfs_dmapi_v2", O_RDWR );
-	if( dmapi_fd == -1 )
-		return -1;
+	dmapi_fd = open( "/dev/dmapi", O_RDWR );
+	if( dmapi_fd == -1 ) {
+		/* Try the old device location, used with 2.4 kernels,
+		 * which still offers a compatible interface.
+		 */
+		dmapi_fd = open( "/proc/fs/xfs_dmapi_v2", O_RDWR );
+		if( dmapi_fd == -1 )
+			return -1;
+	}
 	return 0;
 }
 
